pub struct W(/* private fields */);Expand description
Register CMDCODE writer
Implementations
Sourceimpl W
impl W
Sourcepub fn cmd_phase(&mut self) -> CMD_PHASE_W<'_, 8>
pub fn cmd_phase(&mut self) -> CMD_PHASE_W<'_, 8>
Bits 8:15 - Command phase action
Sourcepub fn code_wdata(&mut self) -> CODE_WDATA_W<'_, 16>
pub fn code_wdata(&mut self) -> CODE_WDATA_W<'_, 16>
Bits 16:23 - This is a multi-purpose field. When CMD_PHASE is Command or Read, this field contains the code for the command (CMD_CODE). When CMD_PHASE is Write, this field contains the command write data (CMD_WDATA).
Methods from Deref<Target = W<CMDCODE_SPEC>>